#
# spec file for package qore
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 David Nichols <david@qore.org>
# Copyright (c) 2014 Petr Vanek <petr@yarpen.cz>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define module_dir %{_libdir}/qore-modules
Name:           qore
Version:        0.8.11
Release:        9.8
Summary:        Multithreaded Programming Language
License:        LGPL-2.1+ or GPL-2.0+ or MIT
Group:          Development/Languages
Url:            http://qore.org
Source:         http://prdownloads.sourceforge.net/qore/qore-%{version}.tar.bz2
Patch:          configure.patch
Patch1:         qore-libtool-2.4.6.patch
BuildRequires:  automake
BuildRequires:  bison
BuildRequires:  bzip2
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  flex >= 2.5.31
BuildRequires:  gcc-c++
BuildRequires:  gmp-devel
BuildRequires:  libbz2-devel
BuildRequires:  libtool
BuildRequires:  mpfr-devel
BuildRequires:  openssl-devel
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  zlib-devel
Requires:       %{_bindir}/env
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

%package -n libqore5
Summary:        The libraries for the qore runtime and qore clients
License:        LGPL-2.0+ or GPL-2.0+ or MIT
Group:          Development/Languages
Provides:       qore-module-api-0.10
Provides:       qore-module-api-0.11
Provides:       qore-module-api-0.12
Provides:       qore-module-api-0.13
Provides:       qore-module-api-0.14
Provides:       qore-module-api-0.15
Provides:       qore-module-api-0.16
Provides:       qore-module-api-0.17
Provides:       qore-module-api-0.18
Provides:       qore-module-api-0.5
Provides:       qore-module-api-0.6
Provides:       qore-module-api-0.7
Provides:       qore-module-api-0.8
Provides:       qore-module-api-0.9

%description -n libqore5
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides the qore library required for all clients using qore
functionality.

%files -n libqore5
%defattr(-,root,root,-)
%{_libdir}/libqore.so.5.12.2
%{_libdir}/libqore.so.5
%doc COPYING.LGPL COPYING.GPL COPYING.MIT README README-LICENSE README-MODULES RELEASE-NOTES ChangeLog AUTHORS WHATISQORE

%post -n libqore5
ldconfig %{_libdir}

%postun -n libqore5
ldconfig %{_libdir}

%package doc
Summary:        API documentation, programming language reference, and Qore example programs
License:        LGPL-2.0+ or GPL-2.0+ or MIT
Group:          Development/Languages

%description doc
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides the HTML documentation for the Qore programming language
and also for user modules delivered with Qore and also example programs.

%files doc
%defattr(-,root,root,-)
%doc docs/lang docs/modules/* examples/ COPYING.LGPL COPYING.GPL COPYING.MIT README-LICENSE

%package devel
Summary:        The header files needed to compile programs using the qore library
License:        LGPL-2.0+ or GPL-2.0+ or MIT
Group:          Development/Languages
Requires:       libqore5 = %{version}-%{release}

%description devel
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides header files needed to compile client programs using the
Qore library.

%files devel
%defattr(-,root,root,-)
%{_bindir}/qpp
%{_bindir}/qdx
%{_libdir}/libqore.so
%{_libdir}/pkgconfig/qore.pc
%dir %{_libdir}/cmake
%{_libdir}/cmake/Qore
%{_includedir}/*

%package devel-doc
Summary:        C++ API documentation for the qore library
License:        LGPL-2.0+ or GPL-2.0+ or MIT
Group:          Development/Languages
Requires:       libqore5 = %{version}-%{release}

%description devel-doc
Qore is a scripting language supporting threading and embedded logic, designed
for applying a flexible scripting-based approach to enterprise interface
development but is also useful as a general purpose language.

This package provides HTML documentation for the C++ API for the Qore library.

%files devel-doc
%defattr(-,root,root,-)
%doc docs/library/html/*

%prep
%setup -q
%patch -p1
%patch1 -p1
# silence the executable warning for examples
find examples -type f|xargs chmod 644
find test -type f|xargs chmod 644
mv test examples

%build
mkdir m4
aclocal
autoreconf -fi
%if "%_lib" == "lib64"
c64=--enable-64bit
%endif
# need to configure with /usr as prefix as this will be used to derive the module directory
CFLAGS="$RPM_OPT_FLAGS" CXXFLAGS="$RPM_OPT_FLAGS" ./configure --prefix=/usr --disable-debug --disable-static $c64 --libdir=%{_libdir}
make %{?_smp_mflags}

%install
mkdir -p %{buildroot}%{_prefix}/bin
mkdir -p %{buildroot}/%{module_dir}/%{version}
mkdir -p %{buildroot}%{_prefix}/man/man1
make install prefix=%{_prefix} DESTDIR=%{buildroot}
rm %{buildroot}/%{_libdir}/libqore.la
%fdupes -s docs

%files
%defattr(-,root,root,-)
%{_bindir}/qore
%{module_dir}
%{_mandir}/man1/qore.1.*

%changelog
* Fri Jun 12 2015 dimstar@opensuse.org
- Add qore-libtool-2.4.6.patch: Remove imported Libtool 2.4.2
  macros from acinclude.m4: this is a terrible hack by upstream to
  not forcibly depend on libtool >= 2.4.2, which has a very bad
  side effect now with libtool 2.4.6 available: the macros conflict
  due the internal API changes inside libtool.
* Sun Jul 13 2014 schwab@linux-m68k.org
- configure.patch: don't use -m32/-m64
* Fri Jun 20 2014 petr@yarpen.cz
- updated to 0.8.11
* Fri Dec 14 2012 petr@yarpen.cz
- spec file reformatted to fit OBS rules
* Thu Nov  8 2012 david@qore.org
- updated to 0.8.6.2
* Fri Oct 26 2012 david@qore.org
- updated to 0.8.6.1
* Sat Sep  1 2012 david@qore.org
- updated to 0.8.6
* Tue May 22 2012 david@qore.org
- updated to 0.8.5
* Mon May 21 2012 david@qore.org
- updated for new doxygen-based documentation, added devel-doc pkg
  for API docs
- updated package descriptions
* Wed Oct 19 2011 david@qore.org
- updated to 0.8.4
* Thu Oct  6 2011 petr.vanek@qoretechnologies.com
- pkg-config
* Sat Mar  5 2011 david@qore.org
- updated to 0.8.3
* Sat Dec 25 2010 david@qore.org
- updated to 0.8.2
* Mon Jun 14 2010 david@qore.org
- updated to 0.8.1
* Tue Nov 17 2009 david_nichols@users.sourceforge.net
- updated to 0.8.0
* Thu Nov  5 2009 david_nichols@users.sourceforge.net
- updated to 0.7.7
* Sun Jul 12 2009 david_nichols@users.sourceforge.net
- updated to 0.7.6
* Sun Jun 21 2009 david_nichols@users.sourceforge.net
- updated to 0.7.5
* Tue Mar  3 2009 david_nichols@users.sourceforge.net
- updated to 0.7.4
* Tue Dec  2 2008 david_nichols@users.sourceforge.net
- updated to 0.7.3
* Tue Nov 25 2008 david_nichols@users.sourceforge.net
- made libqore* the default name for lib package, removed la file
* Sat Nov 22 2008 david_nichols@users.sourceforge.net
- updated to 0.7.2
* Sun Oct 12 2008 david_nichols@users.sourceforge.net
- fixed devel pacakges for suse
* Mon Oct  6 2008 david_nichols@users.sourceforge.net
- released 0.7.0
* Wed Sep  3 2008 david_nichols@users.sourceforge.net
- removed all modules as they are now independent projects
* Mon Sep  1 2008 david_nichols@users.sourceforge.net
- fixed dist tag for suse distributions
- updated for new module directory, added qore-module-api-*
  capability
* Sun Jul 13 2008 david_nichols@users.sourceforge.net
- copied improvements from opensuse rpm and updated based
  on rpmlint output
- updated version to 0.7.0
* Fri Jun 13 2008 david_nichols@users.sourceforge.net
- fixed spec file to support more architectures
* Thu Apr 10 2008 david_nichols@users.sourceforge.net
- updated package to 0.6.2.4 and disabled mssql module build due
- to lack of freetds packages in the build service :-(
* Sun Oct 15 2006 mrueckert@suse.de
- added --enable-64bit to build properly on 64bit biarch
* Sun Oct 15 2006 mrueckert@suse.de
- initial package of 0.5.3
